@@ -6,7 +6,7 @@ from dnn_cool.external.autograd import IAutoGrad
 class TorchAutoGrad(IAutoGrad):
 
     def as_float(self, x):
-        return torch.tensor(x).float()
+        return torch.as_tensor(x).float()
 
     def to_numpy(self, x):
         return x.detach().cpu().numpy()
