@@ -1,10 +1,11 @@
+import numpy as np
 import torch
 
 
 def positive_values(values):
-    if isinstance(values, list):
+    if not isinstance(values, torch.Tensor) and not isinstance(values, np.ndarray):
         return [positive_values(v) for v in values]
-    tensor = values
+    tensor: torch.Tensor = values
     mask = tensor >= 0.
     axes = tuple(range(1, len(mask.shape)))
     if len(axes) > 0:
