@@ -1,5 +1,4 @@
-import torch
-from transformers.modeling_bert import BertOnlyMLMHead
+from transformers.models.bert.modeling_bert import BertOnlyMLMHead
 
 from dnn_cool.external.torch import TorchAutoGrad
 from dnn_cool.losses.torch import ReducedPerSample, LanguageModelCrossEntropyLoss
