@@ -1,8 +1,6 @@
-import torch
-
 from dnn_cool.external.torch import TorchAutoGrad
 from dnn_cool.losses.torch import ReducedPerSample
-from dnn_cool.metrics import get_default_bounded_regression_metrics
+from dnn_cool.metrics.defaults import get_default_bounded_regression_metrics
 from dnn_cool.missing_values import positive_values
 from dnn_cool.modules.torch import SigmoidAndMSELoss
 from dnn_cool.tasks.development.base import TaskForDevelopment
