@@ -1,9 +1,8 @@
-import torch
 from torch import nn
 
 from dnn_cool.external.torch import TorchAutoGrad
 from dnn_cool.losses.torch import ReducedPerSample
-from dnn_cool.metrics import get_default_classification_metrics
+from dnn_cool.metrics.defaults import get_default_classification_metrics
 from dnn_cool.missing_values import positive_values
 from dnn_cool.tasks.development.base import TaskForDevelopment
 
