@@ -55,9 +55,9 @@ def to_broadcastable_smaller(tensor1, tensor2):
     return tensor1.view(*old_axes, *new_axes), tensor2
 
 
-def load_model_from_export(model, full_flow, out_directory: Union[str, Path]) -> nn.Module:
+def load_model_from_export(model, full_flow, out_directory: Union[str, Path], strict=True) -> nn.Module:
     out_directory = Path(out_directory)
-    model.load_state_dict(torch.load(out_directory / 'state_dict.pth'))
+    model.load_state_dict(torch.load(out_directory / 'state_dict.pth'), strict=strict)
     thresholds_path = out_directory / 'tuned_params.pkl'
     if not thresholds_path.exists():
         return model
